<?php
session_start();

// Check if the user is logged in
if (!isset($_SESSION['loggedin']) || !$_SESSION['loggedin']) {
    header('Location: login.php');
    exit();
}

require __DIR__ . '/vendor/autoload.php';  // Make sure this is the correct path to autoload.php

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();


try {
    // Database connection for fetching data from login_key
    $pdo2 = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo2->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);


    // Fetch data from login_key table where id = 1
    $loginKeyStmt = $pdo2->prepare("
        SELECT 
            api, 
            imageUrl, 
            rest_id, 
            rest_name, 
            rest_address, 
            rest_phone, 
            rest_logo 
        FROM login_key 
    ");
    $loginKeyStmt->execute();
    $loginKeyResult = $loginKeyStmt->fetch(PDO::FETCH_ASSOC);

    if ($loginKeyResult) {
        $api = $loginKeyResult['api'];
        $imageUrl = $loginKeyResult['imageUrl'];
        $restaurantId = $loginKeyResult['rest_id'];
        $restaurantName = $loginKeyResult['rest_name'];
        $restaurantAddress = $loginKeyResult['rest_address'];
        $restaurantPhone = $loginKeyResult['rest_phone'];
        $restaurantLogo = $loginKeyResult['rest_logo'];
    } else {
        throw new Exception('No data found for the specified id.');
    }

   
    // Fetch products with price calculations and status
    $stmt = $pdo2->prepare("
   SELECT 
    id,
    name, 
    image,
    category_id, 
    variations,
    status, 
    CASE 
        WHEN pos_price IS NULL OR pos_price = 0 THEN
            CASE 
                WHEN discount_type = 'amount' THEN price - discount
                WHEN discount_type = 'percent' THEN price - (price * discount / 100)
                ELSE price
            END
        ELSE pos_price
    END AS price
FROM 
    food 
WHERE 
    restaurant_id = :restaurant_id
    ");
    $stmt->execute(['restaurant_id' => $restaurantId]);
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Fetch categories with food count
    $catStmt = $pdo2->prepare("
        SELECT categories.id, categories.name, COUNT(food.id) AS food_count 
        FROM categories 
        LEFT JOIN food ON categories.id = food.category_id AND food.restaurant_id = :restaurant_id
        GROUP BY categories.id, categories.name
    ");
    $catStmt->execute(['restaurant_id' => $restaurantId]);
    $categories = $catStmt->fetchAll(PDO::FETCH_ASSOC);

    // Fetch all unpaid orders from the sales table
    $salesStmt = $pdo2->prepare("
        SELECT id, 
            order_amount, 
            payment_method, 
            payment_status, 
            transaction_reference, 
            created_at, 
            delivery_address, 
            coupon_discount_amount, 
            delivery_charge, 
            total_amount, 
            pickup_user, 
            order_status, 
            order_type 
        FROM sales 
        WHERE payment_status = 'unpaid'
    ");
    $salesStmt->execute();
    $unpaidOrders = $salesStmt->fetchAll(PDO::FETCH_ASSOC);

    // Fetch current invoice number
    $invoiceStmt = $pdo2->query("SELECT id FROM sales ORDER BY id DESC LIMIT 1");
    $invoice = $invoiceStmt->fetch(PDO::FETCH_ASSOC);
    $invoiceNumber = $invoice ? $invoice['id'] + 1 : 1;

    // Generate image URLs
    foreach ($products as &$product) {
        $product['image_url'] = rtrim($imageUrl, '/') . '/' . htmlspecialchars($product['image']);
    }
    unset($product);  // Unset reference

    // Restaurant Details  
    $logourl = $restaurantLogo;
    $Restaurantname = $restaurantName;
    $Restaurantaddress = $restaurantAddress;
    $Restaurantphone = $restaurantPhone;

} catch (PDOException $e) {
    // Log the error and provide a user-friendly message
    error_log("Database connection failed: " . $e->getMessage());
    echo "An error occurred. Please try again later.";
} catch (Exception $e) {
    // Handle other exceptions
    error_log($e->getMessage());
    echo "An error occurred. Please try again later.";
}


?>



<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Restaurant POS System</title>
    <!-- Link to the external CSS file -->
    <link rel="stylesheet" href="css/style.css"> <!-- Adjust the path as needed -->
    <link rel="stylesheet" href="css/style-theme.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">
</head>
<body>
    <div id="errorBox" style="display: none;" class="error-box">
    <p id="errorMessage"></p>
</div>
    <div class="header">
        <div class="header-container">
            
        
        <div class="logo-wrap">
            <a href="/"><img src="assets/logo.png"></a>
        </div>
        
        <div class="top-right-buttons">
            <a href="/admin.php" class="admin-btn">Admin <img src="assets/cog.svg" class="cog-img"></a>
            <a id="syncButton" class="refresh-btn"><img src="assets/refresh.svg"></a>
            <a button id="clear-cart-button" class="refresh-btn"><img src="assets/refresh.svg"></a>
        </div>
        </div>
    </div>

    <div class="container">
        <div class="category-list">
            <ul>
                <li><button class="category active-cat" data-category="all">All</button></li>
                <?php foreach ($categories as $category): ?>
                    <?php if ($category['food_count'] > 0): ?>
                        <li><button class="category" data-category="<?php echo htmlspecialchars($category['id']); ?>">
                            <?php echo htmlspecialchars($category['name']); ?>
                        </button></li>
                    <?php endif; ?>
                <?php endforeach; ?>
            </ul>
        </div>
        <div class="product-list-container">
            <div class="search-bar">
                <input type="text" id="search-input" placeholder="Search for products..."><button type="submit" class="product-srh-btn">Search</button>
            </div>
            <div class="product-list">
                <?php foreach ($products as $product): ?>
                    <div class="product"
                         data-id="<?php echo htmlspecialchars($product['id']); ?>"
                         data-name="<?php echo htmlspecialchars($product['name']); ?>"
                         data-price="<?php echo htmlspecialchars($product['price']); ?>"
                         data-category="<?php echo htmlspecialchars($product['category_id']); ?>"
                         data-variations='<?php echo htmlspecialchars($product['variations']); ?>'>
                        <!-- Display the product image -->
                        <div class="product-image">
                            <?php if (!empty($product['image_url'])): ?>
                                <img src="<?php echo htmlspecialchars($product['image_url']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>" />
                            <?php else: ?>
                                <img src="path/to/placeholder-image.jpg" alt="Placeholder Image" />
                            <?php endif; ?>
                        </div>
                        
                        <!-- Product status -->
              <div class="product-status" data-id="<?php echo htmlspecialchars($product['id']); ?>">
    <div class="status-circle"></div>
</div>
                
                        <h3><?php echo htmlspecialchars($product['name']); ?></h3>
                        <h2>£<?php echo htmlspecialchars(number_format($product['price'], 2)); ?></h2>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>

        <div class="sidebar">
            <!-- Toggle Buttons for Views -->
            <div class="side-btns">
                <button class="sidebar-button active-btn" id="invoice-view-btn">Invoice</button>
                <button class="sidebar-button" id="online-view-btn">Online</button>
                <button class="sidebar-button" id="pos-orders-view-btn">POS oders</button> <!-- New POS ORDERS Button -->
            </div>

            <!-- Invoice View -->
            <div id="invoice-view" class="view active">
                <div class="wrap1">
                <p class="invoice-p">Invoice Number: #<?php echo htmlspecialchars($invoiceNumber); ?></p>
                <div id="delivery-address-container" style="display: none;">
                    <h5>Delivery Address:</h5>
                    <p id="delivery-address-text"></p>
                    <button id="edit-address-btn">Edit</button>
                </div>
                <!-- New Pickup Name Container -->
                <div id="pickup-name-container" style="display: none;">
                    <h5>Pickup Name:</h5>
                    <p id="pickup-name-text"></p>
                    <button id="edit-pickup-name-btn">Edit</button>
                </div>

                <div class="serving-option">
                    <h2>Serving Option</h2>
                    <button id="take-away-btn" class="selected"><img src="assets/take-away.png"></button>
                    <button id="eat-in-btn"><img src="assets/dish.png"></button>
                    
                    <button id="delivery-btn"><img src="assets/fast-delivery.png"></button>
                    <button id="pick-up-btn"><img src="assets/pickup.png"></button> <!-- New Pick Up Button -->
                </div>
                </div>
                <h5 class="selected-head">Selected Products</h5>
                <ul id="selected-products"></ul>
           
                <div class="total-wrapper-fixed" id="total-wrapper-fixed">
                <div class="total">
                     <div class="payment-method">
    <!--<h2>Payment Method</h2>-->
    <button id="card-btn" class="payment-btn">Card</button>
       <button id="discount-btn" class="not-payment-btn"><img src="assets/discount.svg"></button>
    <button id="cash-btn" class="payment-btn">Cash</button>
    
   
                 
                    <button id="delivery-charge-btn" class="not-payment-btn"><img src="assets/delivery.svg"></button>
       
  
</div>
<div class="billing-wrap">
    

                    <strong class="price-tiny">Total: <span id="total-price">0.00</span></strong>
                    <div id="discount-container" style="display: none;">
                        <p class="price-tiny">Discount: <span id="discount-amount">0.00</span></p>
                    </div>
                    <div id="delivery-charge-container" style="display: none;">
                        <p class="price-tiny">Delivery Charge: <span id="delivery-charge-amount">0.00</span></p>
                    </div>
                    <div class="total-price-wrap">
                        <span class="amount-span">Amount <br>to Pay:</span> <strong><span id="amount-to-pay">0.00</span></strong>
                    </div>
                    </div>
                    <div class="order-note-container">
    <!--<h2>Order Note</h2>-->
    <textarea id="order-note" placeholder="Enter any notes about the order..."></textarea>
</div>
                </div>
              

              <!-- Order Note Section -->

                
                
                <div class="actions">
                    <button id="save-print-button">Save & Print</button>
                    <button id="save-button">Save</button>
                </div>
                <div class="powered-logo-wrap">
                    <span>Powered by </span><img src="assets/powered.svg">
                </div>
                 </div>
              
            </div>

           
    
 <!-- Print and Done buttons (modals) -->
    <div id="payment-modal" class="modal">
        <div class="modal-content">
            <span class="close" onclick="closeModal('payment-modal')">&times;</span>
            <h2>Select Payment Type</h2>
            <button onclick="finishOrder('cash')">Cash</button>
            <button onclick="finishOrder('card')">Card</button>
        </div>
    </div>

    <div id="confirm-delete-modal" class="modal">
        <div class="modal-content">
            <span class="close" onclick="closeModal('confirm-delete-modal')">&times;</span>
            <h2>Are you sure you want to delete this order?</h2>
            <button onclick="confirmDelete()">Yes</button>
            <button onclick="closeModal('confirm-delete-modal')">No</button>
        </div>
    </div>
   
        <div id="variation-popup">
            <h2>Select Variations</h2>
            <ul id="variation-options"></ul>
            <div class="actions">
                <button id="add-variation" class="submit-btn">Add to Order</button>
                <button id="close-popup" class="cancel-btn">Close</button>
            </div>
        </div>

        <!-- Discount Popup -->
        <div id="discount-popup" class="popup">
            <div class="popup-content">
                <button id="close-discount-popup" class="close-btn">&times;</button>
                <h2>Apply Discount</h2>
                <form id="discount-form">
                    <label for="discount-amount-input">Discount Amount:</label>
                    <input type="number" id="discount-amount-input" required>
                    <button type="submit" class="submit-btn">Apply</button>
                </form>
            </div>
        </div>

        <!-- Delivery Charge Popup -->
        <div id="delivery-charge-popup" class="popup">
            <div class="popup-content">
                <button id="close-delivery-charge-popup" class="close-btn">&times;</button>
                <h2>Set Delivery Charge</h2>
                <form id="delivery-charge-form">
                    <label for="delivery-charge-input">Delivery Charge:</label>
                    <input type="number" id="delivery-charge-input" required>
                    <button type="submit" class="submit-btn">Set</button>
                </form>
            </div>
        </div>

        <!-- Delivery Address Popup -->
        <div id="delivery-address-popup" class="popup">
            <div class="popup-content">
                <h2>Enter Delivery Address</h2>
                <form id="delivery-address-form">
                    <label for="house-number">House Number:</label>
                    <input type="text" id="house-number" name="house_number" >

                    <label for="street">Street:</label>
                    <input type="text" id="street" name="street" >

                    <label for="town">Town:</label>
                    <input type="text" id="town" name="town" >

                    <label for="postcode">Postcode:</label>
                    <input type="text" id="postcode" name="postcode" required>

                    <label for="phone">Phone Number:</label>
                    <input type="tel" id="phone" name="phone" required>

                    <button type="submit" class="submit-btn">Save Address</button>
                    <button type="button" id="close-address-popup" class="cancel-btn">Cancel</button>
                </form>
            </div>
        </div>

        <!-- Pick Up Popup -->
        <div id="pick-up-popup" class="popup">
            <div class="popup-content">
                <button id="close-pick-up-popup" class="close-btn">&times;</button>
                <h2>Enter Customer Name</h2>
                <form id="pick-up-form">
                    <label for="customer-name">Customer Name:</label>
                    <input type="text" id="customer-name" name="customer_name" required>

                    <button type="submit" class="submit-btn">Save</button>
                    <button type="button" id="close-pick-up-popup" class="cancel-btn">Cancel</button>
                </form>
            </div>
        </div>

 <!-- Online View -->
            <div id="online-view" class="view">
                <h2>Online Orders</h2>
                <div id="online-orders-container"></div>

                <!-- Add more content for online orders view here -->
            </div>

           <!-- POS Orders View -->
<div id="pos-orders-view" class="view">
   <h2>Unpaid POS Orders</h2>
    <div id="orders-container">
   </div>


 


<script>

document.addEventListener('DOMContentLoaded', function () {
    var totalWrapper = document.querySelector('.total-wrapper-fixed');
    var selectedProducts = document.querySelector('#selected-products');
    var sidebar = document.querySelector('.sidebar');
    var sidebarWidth = sidebar.offsetWidth;
     var sidebarHeight = sidebar.offsetHeight;
     var wrap1Height = document.querySelector('.wrap1').offsetHeight;
    
    function updateTotalWrapperPosition() {
        var totalWrapperRect = totalWrapper.offsetHeight;
        
      //  var windowHeight = window.innerHeight;
        
        // Calculate available space for #selected-products
        var availableHeight = sidebarHeight - totalWrapperRect - wrap1Height - 70;
  
        selectedProducts.style.maxHeight = availableHeight + 'px';
         totalWrapper.style.width = sidebarWidth - 30 + 'px';
        
        // Scroll to the bottom when the scroll appears or content is added
        scrollToBottom();
    }

    function scrollToBottom() {
        // Scroll #selected-products to the bottom
        selectedProducts.scrollTop = selectedProducts.scrollHeight;
    }

    // Handle window resizing to re-calculate positions
    window.addEventListener('resize', function () {
        updateTotalWrapperPosition();
    });

    // Initial height calculation
    updateTotalWrapperPosition();
    
    // Optionally, you can also add an observer to detect changes in #selected-products content
    const observer = new MutationObserver(function(mutationsList) {
        for (const mutation of mutationsList) {
            if (mutation.type === 'childList') {
                // Scroll to bottom when new items are added
                scrollToBottom();
            }
        }
    });

    // Observe #selected-products for any added content
    observer.observe(selectedProducts, { childList: true });
});








function showError(message) {
    var errorBox = document.getElementById("errorBox");
    var errorMessage = document.getElementById("errorMessage");

    // Set the error message text
    errorMessage.textContent = message;

    // Show the error box
    errorBox.style.display = "block";
    errorBox.classList.remove('fade-out');

    // Hide the error box after 5 seconds
    setTimeout(function() {
        errorBox.classList.add('fade-out');
        setTimeout(function() {
            errorBox.style.display = "none";
        }, 1000); // Wait for fade-out transition to complete
    }, 5000);
}

 document.getElementById('syncButton').addEventListener('click', function() {
            fetch('/sync_food.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                    // Include any data you want to send to sync_food.php
                })
            })
            .then(response => response.json())
            .then(data => {
                if (data.redirect) {
                    window.location.href = data.redirect;
                } else {
                    console.log('Success:', data.success);
                }
            })
            .catch((error) => {
                console.error('Error:', error);
            });
        });


        let productQuantities = {};
        let paymentMethod = null;
        let servingOption = null;
        let discountAmount = 0;
        let deliveryChargeAmount = 0;
        let deliveryAddress = null;
        
        // Check for the default selected serving option when the page loads
document.addEventListener('DOMContentLoaded', () => {
    const defaultButton = document.querySelector('.serving-option button.selected');
    if (defaultButton) {
        const defaultOption = defaultButton.id === 'take-away-btn' ? 'Take-Away' : null; // Add more options as needed
        if (defaultOption) {
            servingOption = defaultOption;
            setServingOption(defaultButton.id);
        }
    }
});

  // Handle product selection and variations
        document.querySelectorAll('.product').forEach(product => {
            product.addEventListener('click', () => {
                const id = product.getAttribute('data-id');
                const name = product.getAttribute('data-name');
                const price = parseFloat(product.getAttribute('data-price'));
                const variations = JSON.parse(product.getAttribute('data-variations'));

                if (variations && variations.length > 0) {
                    showVariationPopup(name, price, variations, id);
                } else {
                    addProductToList(name, price, [], id);
                }
            });
        });

        // Update total and amount to pay
        function updateTotalAndAmountToPay() {
            const subtotal = Object.values(productQuantities).reduce((total, product) => total + (product.price * product.quantity), 0);
            const total = subtotal + deliveryChargeAmount - discountAmount;
            document.getElementById('total-price').textContent = `£${subtotal.toFixed(2)}`;
            document.getElementById('discount-amount').textContent = `£${discountAmount.toFixed(2)}`;
            document.getElementById('delivery-charge-amount').textContent = `£${deliveryChargeAmount.toFixed(2)}`;
            document.getElementById('amount-to-pay').textContent = `£${total.toFixed(2)}`;
        }


//online orders
// URL for fetching online orders
const onlineOrdersApi = '<?php echo $api; ?>online_orders_api.php?id=<?php echo $restaurantId; ?>';

async function fetchAndDisplayOnlineOrders() {
    try {
        const response = await fetch(onlineOrdersApi);

        if (!response.ok) {
            throw new Error('Network response was not ok ' + response.statusText);
        }

        const data = await response.json();

        const ordersContainer = document.getElementById('online-orders-container');
        ordersContainer.innerHTML = ''; // Clear existing content

        if (!Array.isArray(data.onlineOrders)) {
            throw new Error('Fetched data is not an array');
        }

        data.onlineOrders.forEach(order => {
            const orderBox = document.createElement('div');
            orderBox.classList.add('order-box', order.order_type.toLowerCase());

            // Parse the delivery address if it's in JSON format
            let deliveryAddressHtml = '';
            if (order.delivery_address) {
                try {
                    const address = JSON.parse(order.delivery_address);
                    deliveryAddressHtml = `
                        <div class="delivery-address">
                            ${address.house_number} ${address.street}, ${address.town}, ${address.postcode}
                            <br>Phone: ${order.phone}
                        </div>
                    `;
                } catch (e) {
                    console.error('Error parsing delivery address:', e);
                }
            }

            // Create the main content
            
            // Function to format date in 'YYYY-MM-DD HH:mm:ss' format
function formatDate(dateString) {
    const date = new Date(dateString);
    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0');
    const day = String(date.getDate()).padStart(2, '0');
    const hours = String(date.getHours()).padStart(2, '0');
    const minutes = String(date.getMinutes()).padStart(2, '0');
    const seconds = String(date.getSeconds()).padStart(2, '0');
    
    return `${year}-${month}-${day} ${hours}:${minutes}:${seconds}`;
}
          // Extract values and compute the necessary amounts
const totalAmount = parseFloat(order.order_amount) || 0;
const discount = parseFloat(order.coupon_discount_amount) || 0;
const deliveryCharge = parseFloat(order.delivery_charge) || 0;
const orderAmount = (totalAmount + discount - deliveryCharge).toFixed(2);
const orderTime = formatDate(order.created_at); // Format order time
const orderStatus = order.order_status; // Assuming this is a string

const detailsHtml = `
<div class="order-time">Order Time: ${orderTime}</div>
    <div class="order-status">Status: ${orderStatus}</div>
    
    <div class="order-id">Order #${order.id}</div>
    <div class="customer-name">Customer: ${order.f_name} ${order.l_name}</div>

    <div class="total-amount">Total: £${totalAmount}</div>
    
    ${order.order_type === 'Delivery' ? deliveryAddressHtml : ''}
    ${order.order_type === 'Pick-Up' ? `<div class="pickup-user">${order.pickup_user}</div>` : ''}
`;


            // Create the meta section
            const metaHtml = `
                <div class="order-type">Type: ${order.order_type}</div>
                <div class="order-status">Status: ${order.payment_status}</div>
                <div class="order-actions">
                    <button onclick="printOnlineOrder(${order.id})" class="print-order-btn">PRINT</button>
                    <button onclick="showOrderStatusModal(${order.id})" class="status-order-btn">STATUS</button>
                </div>
            `;

            // Set the inner HTML
            orderBox.innerHTML = `
                <div class="order-details">${detailsHtml}</div>
                <div class="order-meta">${metaHtml}</div>
            `;

            ordersContainer.appendChild(orderBox);
        });
    } catch (error) {
        console.error('Error fetching online orders:', error);
    }
}

// Function to print the order using the separate print API
function printOnlineOrder(orderId) {
    fetch(`<?php echo $api; ?>print_online_order_api.php?id=${orderId}`)
        .then(response => response.json())
        .then(data => {
            if (data.error) {
                console.error('Error fetching order data:', data.error);
               // alert('Failed to fetch order data. Please try again.');
                showError('Failed to fetch order data. Please try again.');
                return;
            }

            const orderInfo = data.orderInfo;
            const orderDetails = data.orderDetails;
            const orderVariations = data.orderVariations || []; // Ensure this is an array, even if empty

            const subtotal = orderDetails.reduce((total, item) => {
                const basePrice = parseFloat(item.price) || 0;
                const discount = parseFloat(item.discount_on_food) || 0;
                const priceAfterDiscount = basePrice - discount;
                return total + (priceAfterDiscount * item.quantity);
            }, 0);

            const discountAmount = parseFloat(orderInfo.coupon_discount_amount) || 0;
            const deliveryChargeAmount = parseFloat(orderInfo.delivery_charge) || 0;
            const totalAmount = subtotal - discountAmount + deliveryChargeAmount;

            let deliveryAddressHtml = '';
            if (orderInfo.order_type.toLowerCase() === 'delivery') {
                // Delivery order
                if (orderInfo.delivery_address) {
                    try {
                        const addressData = typeof orderInfo.delivery_address === 'string' ? JSON.parse(orderInfo.delivery_address) : orderInfo.delivery_address;
                        if (addressData) {
                            const contactPersonName = addressData.contact_person_name || 'N/A';
                            const contactPersonNumber = addressData.contact_person_number || 'N/A';
                            const address = addressData.address || 'N/A';
                            deliveryAddressHtml = `
                                <h3>Delivery Address:</h3>
                                
                                    <h5>${address}<br>
                                    Name: ${contactPersonName}<br></h5>
                                    <h3>
                                    Phone: ${contactPersonNumber}
                                </h3>
                            `;
                        } else {
                            deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                        }
                    } catch (e) {
                        console.error('Error parsing delivery address:', e);
                        deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                    }
                }
            } else {
                // Non-delivery order
                const customerFirstName = orderInfo.f_name || 'N/A';
                const customerLastName = orderInfo.l_name || 'N/A';
                const customerName = `${customerFirstName} ${customerLastName}`;
                const customerPhone = orderInfo.phone || 'N/A';
                deliveryAddressHtml = `
                    <h3>Customer Details:</h3>
                    <p>
                        Name: ${customerName}<br>
                        Phone: ${customerPhone}
                    </p>
                `;
            }

            const receiptContent = `
                <html>
                <head>
                    <style>
    @media print {
        @page {
            size: 80mm;
            margin: 0;
        }
        body {
            font-family: Arial, sans-serif;
            font-size: 12px;
            width: 80mm;
            margin: 0;
        }
        .receipt {
            width: 80mm;
            padding: 10mm;
            border: 1px solid #ddd;
        }

        /* Existing styles */
        .text-center {
            text-align: center;
        }
        .d-flex {
            display: flex;
            justify-content: space-between;
        }
        .text-right {
            text-align: right;
        }
        .text-muted {
            color: #6c757d;
        }
        .fw-500 {
            font-weight: 500;
        }
        .border-bottom-dashed {
            border-bottom: 1px dashed #979797;
        }
        .mt-1 {
            margin-top: 0.25rem;
        }
        .mb-1 {
            margin-bottom: 0.25rem;
        }
        .initial-38-2 {
            max-width: 100%;
            height: auto;
        }
    }
</style>

                </head>
                <body>
                    <div class="receipt">
                        <div class="text-center pt-3">
                            <img src="<?php echo htmlspecialchars($logourl); ?>" class="initial-38-2" alt="">
                        </div>
                        <div class="text-center pt-3 mb-3">
                            <h5 class="initial-38-3"><?php echo htmlspecialchars($Restaurantname); ?></h5>
                            <h5 class="text-break initial-38-4"><?php echo htmlspecialchars($Restaurantaddress); ?></h5>
                            <h5 class="text-muted">${new Date().toLocaleDateString('en-GB')} ${new Date().toLocaleTimeString('en-GB')}</h5>
                            <h5><span>Phone</span> <span>:</span> <span><?php echo htmlspecialchars($Restaurantphone); ?></span></h5>
                        </div>

                        <h5 class="d-flex">
                            <span>Order Type</span>
                            <span>${orderInfo.order_type}</span>
                        </h5>

                        <div class="border border-dashed border-secondary p-3 rounded">
                            <h5 class="d-flex">
                                <span class="text-muted">Order ID</span>
                                <span>${orderInfo.id}</span>
                            </h5>
                        </div>

                        ${deliveryAddressHtml}

    ${orderInfo.delivery_instruction ? `<p><strong>Delivery Instruction:</strong> ${orderInfo.delivery_instruction}</p>` : ''}

                        <h3>Products:</h3>
                        <ul>
                            ${orderDetails.map((item, index) => {
                                let foodDetails;
                                try {
                                    foodDetails = JSON.parse(item.food_details);
                                } catch (error) {
                                    console.error('Error parsing food details:', error);
                                    foodDetails = { name: 'Unknown Item' }; // Fallback
                                }

                                const itemName = foodDetails.name || 'Unknown Item';

                                // Calculate price after discount
                                const Itemqty = parseFloat(item.quantity) || 0;
                                const basePrice = parseFloat(item.price) || 0;
                                const discount = parseFloat(item.discount_on_food) || 0;
                                const priceAfterDiscount = Itemqty*(basePrice - discount);

                                // Get variations for this item from orderVariations
                                const variations = (orderVariations[index] && Array.isArray(orderVariations[index])) ? orderVariations[index] : [];
                                const itemVariations = variations.length > 0 ? variations.map(variation => `
                                    <div class="variation">
                                        ${variation.name ? `<span>${variation.name}:</span>` : ''}
                                        ${variation.values.map(value => `
                                            <span>${value.label}</span>
                                        `).join(', ')}
                                    </div>
                                `).join('') : ''; // Leave blank if no variations

                                return `
                                    <li>
                                        ${item.quantity} x ${itemName} - £${priceAfterDiscount.toFixed(2)}
                                        ${itemVariations ? `<div>${itemVariations}</div>` : ''} <!-- Only add variations if they exist -->
                                    </li>
                                `;
                            }).join('')}
                        </ul>

                        <div class="border-bottom-dashed mb-3"></div>
                        <div>
                           <div class="px-3">
                    <dl class="row text-right">
                        <dt class="col-6 text-left text-muted">Items Price</dt>
                        <dd class="col-6">£${subtotal.toFixed(2)}</dd>
                        <dd class="col-12 border-bottom-dashed mb-2"></dd>
                        <dt class="col-6 text-left text-muted">Discount</dt>
                        <dd class="col-6">- £${parseFloat(orderInfo.coupon_discount_amount).toFixed(2)}</dd>
                        <dt class="col-6 text-left text-muted">Delivery charge</dt>
                        <dd class="col-6">£${parseFloat(orderInfo.delivery_charge).toFixed(2)}</dd>
                        <dd class="col-12 border-bottom-dashed mb-2"></dd>
                        <dt class="col-6 text-left fw-500 fz-20px">Total</dt>
                        <dd class="col-6 fz-20px fw-500">£${parseFloat(orderInfo.order_amount).toFixed(2)}</dd>
                    </dl>
                </div>
            </div>
<!-- Additional Information Section -->
<div class="px-3 mt-1">
   <dd class="col-12 border-bottom-dashed mb-2"></dd>
    ${orderInfo.order_note ? `<p><strong>Order Note:</strong> ${orderInfo.order_note}</p>` : ''}
    
    ${orderInfo.unavailable_item_note ? `<p><strong>If Item Note:</strong> ${orderInfo.unavailable_item_note}</p>` : ''}
</div>
                        <dd class="col-12 border-bottom-dashed mb-2"></dd>
                        <div class="d-flex flex-row justify-content-between">
                            <span class="text-capitalize d-flex"><span>Paid by</span> <span>:</span> <span>${orderInfo.payment_method}</span></span>
                        </div>
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <h5 class="text-center pt-1 justify-content-center mb-0">
                            <span class="d-block fw-500">THANK YOU</span>
                        </h5>
                        <div class="text-center">For ordering food from <?php echo htmlspecialchars($Restaurantname); ?></div>
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <span class="d-block text-center">© <?php echo date("Y"); ?> <?php echo htmlspecialchars($Restaurantname); ?>. All rights reserved Powered By Foodspot</span>
                    </div>
                </body>
                </html>
            `;

            // Create a hidden iframe for printing
            const iframe = document.createElement('iframe');
            iframe.style.position = 'absolute';
            iframe.style.width = '0';
            iframe.style.height = '0';
            iframe.style.border = 'none';
            document.body.appendChild(iframe);

            const iframeDoc = iframe.contentWindow.document;
            iframeDoc.open();
            iframeDoc.write(receiptContent);
            iframeDoc.close();

            iframe.contentWindow.focus();
            iframe.contentWindow.print();

            // Clean up after printing
            iframe.addEventListener('load', () => {
                iframe.contentWindow.onafterprint = () => {
                    document.body.removeChild(iframe);
                };
            });
        })
        .catch(error => {
            console.error('Error fetching order data:', error);
           // alert('Failed to fetch order data. Please try again.');
            showError('Failed to fetch order data. Please try again.');
        });
}

// Initialize fetch and display when the page loads
window.onload = fetchAndDisplayOnlineOrders;








//pos orders 
const posordersapi = 'connect_pos_orders.php';

async function fetchAndDisplayOrders() {
    try {
        const response = await fetch(posordersapi);

        if (!response.ok) {
            throw new Error('Network response was not ok ' + response.statusText);
        }

        const data = await response.json();

        const ordersContainer = document.getElementById('orders-container');
        ordersContainer.innerHTML = ''; // Clear existing content

        if (!Array.isArray(data.posOrders)) {
            throw new Error('Fetched data is not an array');
        }

        data.posOrders.forEach(order => {
            const orderBox = document.createElement('div');
            orderBox.classList.add('order-box', order.order_type.toLowerCase());

            // Parse the delivery address if it's in JSON format
            let deliveryAddressHtml = '';
            if (order.delivery_address) {
                try {
                    const address = JSON.parse(order.delivery_address);
                    deliveryAddressHtml = `
                        <div class="delivery-address">
                            ${address.house_number} ${address.street}, ${address.town}, ${address.postcode}
                            <br>Phone: ${address.phone}
                        </div>
                    `;
                } catch (e) {
                    console.error('Error parsing delivery address:', e);
                }
            }

            // Create the main content
            function formatDateTime(dateString) {
    const date = new Date(dateString);
    const dateFormatted = date.toLocaleDateString('en-GB'); // 'YYYY-MM-DD' format
    const timeFormatted = date.toLocaleTimeString('en-GB', { hour: '2-digit', minute: '2-digit', second: '2-digit' }); // 'HH:mm:ss' format
    return `${dateFormatted} ${timeFormatted}`;
}

// Extract and format date and time
const orderDateTime = formatDateTime(order.created_at);
            const amount = parseFloat(order.order_amount);
const discount = parseFloat(order.coupon_discount_amount) || 0;
const deliveryCharge = parseFloat(order.delivery_charge) || 0;
const totalAmount = (amount - discount + deliveryCharge).toFixed(2);

const detailsHtml = `
    <div class="order-id">Order #${order.id}</div>

    <div class="total-amount">Total: £${totalAmount}</div>
    ${order.order_type === 'Delivery' ? deliveryAddressHtml : ''}
    ${order.order_type === 'Pick-Up' ? `<div class="pickup-user">${order.pickup_user}</div>` : ''}
`;


            // Create the meta section
            const metaHtml = `
                <div class="order-date">Date: ${orderDateTime}</div>
                <div class="order-type">Type: ${order.order_type}</div>
                <div class="order-actions">
                    
<button onclick="printOrder(${order.id})" class="print-order-btn">PRINT</button>

                    <button onclick="showPaymentModal(${order.id})" class="status-order-btn">DONE</button>
                    <button onclick="showDeleteConfirmModal(${order.id})" class="remove-order-btn">X</button>
                </div>
            `;

            // Set the inner HTML
            orderBox.innerHTML = `
                <div class="order-details">${detailsHtml}</div>
                <div class="order-meta">${metaHtml}</div>
            `;

            ordersContainer.appendChild(orderBox);
        });
    } catch (error) {
        console.error('Error fetching orders:', error);
    }
}




function printOrder(orderId) {
    fetch(`connect_pos_order_print.php?id=${orderId}`)
        .then(response => response.json())
        .then(data => {
            if (data.error) {
                console.error('Error fetching order data:', data.error);
               // alert('Failed to fetch order data. Please try again.');
                showError('Failed to fetch order data. Please try again.');
                return;
            }

            const orderInfo = data.orderInfo;
            const orderDetails = data.orderDetails;

            const subtotal = orderDetails.reduce((total, item) => {
                const itemTotalPrice = parseFloat(item.price) * parseFloat(item.quantity);
                return total + itemTotalPrice;
            }, 0);
            const discountAmount = parseFloat(orderInfo.coupon_discount_amount) || 0;
            const deliveryChargeAmount = parseFloat(orderInfo.delivery_charge) || 0;
            const totalAmount = parseFloat(orderInfo.total_amount) || 0;

            let deliveryAddressHtml = '';
            if (orderInfo.order_type.toLowerCase() === 'delivery' && orderInfo.delivery_address) {
                try {
                    const address = typeof orderInfo.delivery_address === 'string' ? JSON.parse(orderInfo.delivery_address) : orderInfo.delivery_address;
                    if (address && address.contact_person_name && address.contact_person_number && address.address) {
                        deliveryAddressHtml = `
                            <h3>Delivery Address:</h3>
                            <p>
                                ${address.contact_person_name}<br>
                                Phone: ${address.contact_person_number}<br>
                                Address: ${address.address}
                            </p>
                        `;
                    } else {
                        deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                    }
                } catch (e) {
                    console.error('Error parsing delivery address:', e);
                    deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                }
            } else if (orderInfo.order_type.toLowerCase() === 'pick-up') {
                deliveryAddressHtml = `
                    <h3>Pick Up By ${orderInfo.f_name} ${orderInfo.l_name}</h3>
                    <p>Phone: ${orderInfo.phone}</p>
                `;
            }

            const receiptContent = `
                <html>
                <head>
                    <style>
                        @media print {
                            @page {
                                size: 80mm;
                                margin: 0;
                            }
                            body {
                                font-family: Arial, sans-serif;
                                font-size: 12px;
                                width: 80mm;
                                margin: 0;
                            }
                            .receipt {
                                width: 80mm;
                                padding: 10mm;
                                border: 1px solid #ddd;
                            }
                            .text-center {
                                text-align: center;
                            }
                            .d-flex {
                                display: flex;
                                justify-content: space-between;
                            }
                            .text-right {
                                text-align: right;
                            }
                            .text-muted {
                                color: #6c757d;
                            }
                            .fw-500 {
                                font-weight: 500;
                            }
                            .border-bottom-dashed {
                                border-bottom: 1px dashed #979797;
                            }
                            .mt-1 {
                                margin-top: 0.25rem;
                            }
                            .mb-1 {
                                margin-bottom: 0.25rem;
                            }
                            .initial-38-2 {
                                max-width: 100%;
                                height: auto;
                            }
                        }
                    </style>
                </head>
                <body>
                    <div class="receipt">
                        <div class="text-center pt-3">
                             <img src="<?php echo htmlspecialchars($logourl); ?>" class="initial-38-2" alt="">
                        </div>
                        <div class="text-center pt-3 mb-3">
                           <h5 class="initial-38-3"><?php echo htmlspecialchars($Restaurantname); ?></h5>
                           <h5 class="text-break initial-38-4"><?php echo htmlspecialchars($Restaurantaddress); ?></h5>
                           <h5 class="text-muted">${new Date().toLocaleDateString('en-GB')} ${new Date().toLocaleTimeString('en-GB')}</h5>
                           <h5><span>Phone</span> <span>:</span> <span><?php echo htmlspecialchars($Restaurantphone); ?></span></h5>
                        </div>

                        <h5 class="d-flex">
                            <span>Order Type</span>
                            <span>${orderInfo.order_type}</span>
                        </h5>

                        <div class="border border-dashed border-secondary p-3 rounded">
                            <h5 class="d-flex">
                                <span class="text-muted">Order ID</span>
                                <span>${orderInfo.id}</span>
                            </h5>
                        </div>

                        ${deliveryAddressHtml}

                        <h3>Products:</h3>
                        <ul>
                            ${orderDetails.map(item => {
                                // Calculate total price for this item
                                const itemTotalPrice = parseFloat(item.quantity) * parseFloat(item.price);
                                return `
                                    <li>
                                        ${item.quantity} x ${item.food_details} - £${itemTotalPrice.toFixed(2)}
                                    </li>
                                `;
                            }).join('')}
                        </ul>

                        <div class="px-3">
                            <dl class="row text-right">
                                <dt class="col-6 text-left text-muted">Items Price</dt>
                                <dd class="col-6">£${subtotal.toFixed(2)}</dd>
                                <dd class="col-12 border-bottom-dashed mb-2"></dd>
                                <dt class="col-6 text-left text-muted">Discount</dt>
                                <dd class="col-6">- £${parseFloat(orderInfo.coupon_discount_amount).toFixed(2)}</dd>
                                <dt class="col-6 text-left text-muted">Delivery charge</dt>
                                <dd class="col-6">£${parseFloat(orderInfo.delivery_charge).toFixed(2)}</dd>
                                <dd class="col-12 border-bottom-dashed mb-2"></dd>
                                <dt class="col-6 text-left fw-500 fz-20px">Total</dt>
                                <dd class="col-6 fz-20px fw-500">£${parseFloat(orderInfo.total_amount).toFixed(2)}</dd>
                            </dl>
                        </div>

                        ${orderInfo.order_note ? `<h5>Order Note:</h5><p>${orderInfo.order_note}</p>` : ''}
                        ${orderInfo.unavailable_item_note ? `<h5>Unavailable Note:</h5><p>${orderInfo.unavailable_item_note}</p>` : ''}
                        ${orderInfo.delivery_instruction ? `<h5>Delivery Instructions:</h5><p>${orderInfo.delivery_instruction}</p>` : ''}
                        
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <h5 class="text-center pt-1 justify-content-center mb-0">
                            <span class="d-block fw-500">THANK YOU</span>
                        </h5>
                        <div class="text-center">For ordering food from <?php echo htmlspecialchars($Restaurantname); ?></div>
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <span class="d-block text-center">© <?php echo date("Y"); ?> <?php echo htmlspecialchars($Restaurantname); ?>. All rights reserved Powered By Foodspot</span>
                    </div>
                </body>
                </html>
            `;

            // Create a hidden iframe for printing
            const iframe = document.createElement('iframe');
            iframe.style.position = 'absolute';
            iframe.style.width = '0';
            iframe.style.height = '0';
            iframe.style.border = 'none';
            document.body.appendChild(iframe);

            const iframeDoc = iframe.contentWindow.document;
            iframeDoc.open();
            iframeDoc.write(receiptContent);
            iframeDoc.close();

            iframe.contentWindow.focus();
            iframe.contentWindow.print();

            // Clean up after printing
            iframe.addEventListener('load', () => {
                iframe.contentWindow.onafterprint = () => {
                    document.body.removeChild(iframe);
                };
            });
        })
        .catch(error => {
            console.error('Error fetching order data:', error);
            //alert('Failed to fetch order data. Please try again.');
            showError('Failed to fetch order data. Please try again.');
        });
}






function showPaymentModal(orderId) {
    const modal = document.getElementById('payment-modal');
    modal.style.display = 'block';
    window.currentOrderId = orderId; // Store the order ID for further actions
}

function finishOrder(paymentType) {
    // Logic to update the order's payment status and method
    console.log('Finish order with payment type:', paymentType, 'for order ID:', window.currentOrderId);

    // Example: Update the order status via an API call
    fetch(`connect_pos_order_update.php`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            orderId: window.currentOrderId,
            paymentStatus: 'paid',
            paymentMethod: paymentType
        }),
    })
    .then(response => response.json())
    .then(data => {
        console.log('Order updated:', data);
        // Close the modal
        closeModal('payment-modal');
        // Optionally refresh orders
        fetchAndDisplayOrders();
    })
    .catch(error => console.error('Error updating order:', error));
}

function showDeleteConfirmModal(orderId) {
    const modal = document.getElementById('confirm-delete-modal');
    modal.style.display = 'block';
    window.currentOrderId = orderId; // Store the order ID for further actions
}

function confirmDelete() {
    // Logic to delete the order
    console.log('Delete order:', window.currentOrderId);

    // Example: Delete the order via an API call
    fetch(`connect_pos_order_delete.php`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            orderId: window.currentOrderId
        }),
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            console.log('Order deleted:', data.message);
            // Optionally refresh orders
            fetchAndDisplayOrders();
        } else {
            console.error('Error deleting order:', data.message);
          //  alert('Error deleting order: ' + data.message);
            showError('Error deleting order: ' + data.message);
        }
        // Close the modal
        closeModal('confirm-delete-modal');
    })
    .catch(error => {
        console.error('Error deleting order:', error);
    //    alert('An error occurred while deleting the order.');
        showError('An error occurred while deleting the order.');
        // Close the modal
        closeModal('confirm-delete-modal');
    });
}

// Example function to open a modal
function openModal(modalId) {
    const modal = document.getElementById(modalId);
    if (modal) {
        modal.style.display = 'block';
    }
}

// Example function to close a modal
function closeModal(modalId) {
    const modal = document.getElementById(modalId);
    if (modal) {
        modal.style.display = 'none';
    }
}

// Function to set the current order ID when opening the delete confirmation modal
function setCurrentOrderId(orderId) {
    window.currentOrderId = orderId;
}


// Call the function when the page loads
fetchAndDisplayOrders();

        
        
        
        
        
       document.querySelectorAll('.category').forEach(category => {
    category.addEventListener('click', () => {
        // Remove active class from all categories
        document.querySelectorAll('.category').forEach(cat => {
            cat.classList.remove('active-cat');
        });

        // Add active class to the clicked category
        category.classList.add('active-cat');

        const selectedCategory = category.getAttribute('data-category');

        // Show or hide products based on the selected category
        document.querySelectorAll('.product').forEach(product => {
            if (selectedCategory === 'all' || product.getAttribute('data-category') === selectedCategory) {
                product.style.display = 'block';
            } else {
                product.style.display = 'none';
            }
        });
    });
});


        document.getElementById('search-input').addEventListener('input', (e) => {
            const searchQuery = e.target.value.toLowerCase();
            document.querySelectorAll('.product').forEach(product => {
                const name = product.getAttribute('data-name').toLowerCase();
                if (name.includes(searchQuery)) {
                    product.style.display = 'block';
                } else {
                    product.style.display = 'none';
                }
            });
        });

        document.getElementById('cash-btn').addEventListener('click', () => {
            paymentMethod = 'cash';
            document.getElementById('cash-btn').classList.add('selected');
            document.getElementById('card-btn').classList.remove('selected');
        });

        document.getElementById('card-btn').addEventListener('click', () => {
            paymentMethod = 'card';
            document.getElementById('card-btn').classList.add('selected');
            document.getElementById('cash-btn').classList.remove('selected');
        });

        document.getElementById('eat-in-btn').addEventListener('click', () => {
            servingOption = 'Eat-In';
            setServingOption('eat-in-btn');
        });

        document.getElementById('take-away-btn').addEventListener('click', () => {
            servingOption = 'Take-Away';
            setServingOption('take-away-btn');
        });

// Function to clear Delivery Address
function clearDeliveryAddress() {
    // Clear the delivery address text
    document.getElementById('delivery-address-text').textContent = '';

    // Hide the delivery address container
    document.getElementById('delivery-address-container').style.display = 'none';

    // Clear the input fields in the delivery address popup
    document.getElementById('house-number').value = '';
    document.getElementById('street').value = '';
    document.getElementById('town').value = '';
    document.getElementById('postcode').value = '';
    document.getElementById('phone').value = '';
}

// Function to set Serving Option and update UI
function setServingOption(optionId) {
    // Logic to handle the UI update based on the selected serving option
    // Add/remove classes or update display here
    document.querySelectorAll('.serving-option button').forEach(button => {
        button.classList.remove('active');
    });
    document.getElementById(optionId).classList.add('active');
}

// Event listener for Delivery button
document.getElementById('delivery-btn').addEventListener('click', () => {
    servingOption = 'Delivery';
    setServingOption('delivery-btn');
    document.getElementById('delivery-address-popup').style.display = 'flex';
});

// Event listener for Eat-In button
document.getElementById('eat-in-btn').addEventListener('click', () => {
    servingOption = 'Eat-In';
    setServingOption('eat-in-btn');
    clearDeliveryAddress();  // Clear delivery address when switching to Eat-In
    clearPickupName();       // Assuming you have a clearPickupName function similar to clearDeliveryAddress
});

// Event listener for Take-Away button
document.getElementById('take-away-btn').addEventListener('click', () => {
    servingOption = 'Take-Away';
    setServingOption('take-away-btn');
    clearDeliveryAddress();  // Clear delivery address when switching to Take-Away
    clearPickupName();       // Assuming you have a clearPickupName function similar to clearDeliveryAddress
});

// Event listener for Pick Up button
document.getElementById('pick-up-btn').addEventListener('click', () => {
    servingOption = 'Pick-Up';
    setServingOption('pick-up-btn');
    clearDeliveryAddress();  // Clear delivery address when switching to Pick Up
    document.getElementById('pick-up-popup').style.display = 'flex';
});

// Close delivery address popup
document.getElementById('close-address-popup').addEventListener('click', () => {
    document.getElementById('delivery-address-popup').style.display = 'none';
});

// Handle delivery address form submission
document.getElementById('delivery-address-form').addEventListener('submit', (e) => {
    e.preventDefault();
    
    // Collect delivery address data
    deliveryAddress = {
        house_number: document.getElementById('house-number').value,
        street: document.getElementById('street').value,
        town: document.getElementById('town').value,
        postcode: document.getElementById('postcode').value,
        phone: document.getElementById('phone').value,
    };

    // Update delivery address display
    updateDeliveryAddressDisplay();

    // Close popup
    document.getElementById('delivery-address-popup').style.display = 'none';
});

// Function to update delivery address display
function updateDeliveryAddressDisplay() {
    if (deliveryAddress) {
        var addressText = `${deliveryAddress.house_number}, ${deliveryAddress.street}, ${deliveryAddress.town}, ${deliveryAddress.postcode} (${deliveryAddress.phone})`;
        document.getElementById('delivery-address-text').textContent = addressText;
        document.getElementById('delivery-address-container').style.display = 'block';
    }
}

// Example function to clear Pickup Name
function clearPickupName() {
    document.getElementById('pickup-name-text').textContent = '';
    document.getElementById('pickup-name-container').style.display = 'none';
    document.getElementById('customer-name').value = '';
}

// Set serving option as selected
function setServingOption(selectedId) {
    document.querySelectorAll('#eat-in-btn, #take-away-btn, #delivery-btn, #pick-up-btn').forEach(btn => {
        btn.classList.remove('selected');
    });
    document.getElementById(selectedId).classList.add('selected');
}

// Save order with or without printing receipt
document.getElementById('save-print-button').addEventListener('click', () => {
    saveOrder(true);
});

document.getElementById('save-button').addEventListener('click', () => {
    saveOrder(false);
});



function saveOrder(printReceipt) {
    // Validation
    if (!paymentMethod) return showError('Please select a payment method.'); //alert('Please select a payment method.');
    if (!servingOption) return showError('Please select a serving option.'); //alert('Please select a serving option.');

    // Collect selected items
    const selectedItems = Object.entries(productQuantities).map(([key, product]) => ({
        id: product.id,
        name: product.name,
        price: product.price,
        quantity: product.quantity,
        variations: product.variations
    }));

    if (selectedItems.length === 0) return showError('No products selected.'); //alert('No products selected.');
 const orderNote = document.getElementById('order-note').value;
    // Prepare request data
    const subtotal = selectedItems.reduce((sum, item) => sum + (item.price * item.quantity), 0);
    const requestData = {
        paymentMethod,
        servingOption,
        products: selectedItems,
        coupon_discount_amount: discountAmount,
        delivery_charge: deliveryChargeAmount,
        total_amount: subtotal + deliveryChargeAmount - discountAmount,
        pickupName: servingOption === 'Pick-Up' ? pickupName : null,
        deliveryAddress: servingOption === 'Delivery' ? deliveryAddress : null,
        orderNote 
    };

    // Send request
    fetch('save_order.php', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(requestData)
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            if (printReceipt) generateAndPrintReceipt(data.invoiceNumber);
            window.location.reload();
        } else {
           // alert('Failed to save order.');
            showError('Failed to save order.');
        }
    })
    .catch(error => {
        console.error('Error:', error);
     //   alert('An error occurred while saving the order.');
        showError('An error occurred while saving the order.');
    });
}






function generateAndPrintReceipt(invoiceNumber) {
    // Calculate subtotal
    const subtotal = Object.values(productQuantities).reduce((total, product) => 
        total + (product.price * product.quantity), 0);

    // Format the delivery address if serving option is delivery
    let deliveryAddressHtml = '';
    if (servingOption.toLowerCase() === 'delivery' && deliveryAddress) {
        deliveryAddressHtml = `
            <h3>Delivery Address:</h3>
            <p>
                ${deliveryAddress.house_number}, ${deliveryAddress.street}, ${deliveryAddress.town}, ${deliveryAddress.postcode}<br>
                Phone: ${deliveryAddress.phone}
            </p>
        `;
    }

    // Format the pickup name if serving option is pick-up
    let pickupNameHtml = '';
    if (servingOption.toLowerCase() === 'pick-up' && pickupName) {
        pickupNameHtml = `
            <h3>Pick Up By ${pickupName}</h3>
        `;
    }

    // Format the receipt content
    const receiptContent = `
        <html>
        <head>
            <style>
                @media print {
                    @page {
                        size: 80mm;
                        margin: 0;
                    }
                    body {
                        font-family: Arial, sans-serif;
                        font-size: 12px;
                        width: 80mm;
                        margin: 0;
                    }
                    .receipt {
                        width: 80mm;
                        padding: 10mm;
                        border: 1px solid #ddd;
                    }
                    .text-center {
                        text-align: center;
                    }
                    .d-flex {
                        display: flex;
                        justify-content: space-between;
                    }
                    .text-right {
                        text-align: right;
                    }
                    .text-muted {
                        color: #6c757d;
                    }
                    .fw-500 {
                        font-weight: 500;
                    }
                    .border-bottom-dashed {
                        border-bottom: 1px dashed #979797;
                    }
                    .mt-1 {
                        margin-top: 0.25rem;
                    }
                    .mb-1 {
                        margin-bottom: 0.25rem;
                    }
                    .initial-38-2 {
                        max-width: 100%;
                        height: auto;
                    }
                }
            </style>
        </head>
        <body>
            <div class="receipt">
                <div class="text-center pt-3">
                    <img src="<?php echo htmlspecialchars($logourl); ?>" class="initial-38-2" alt="">
                </div>
                <div class="text-center pt-3 mb-3">
                    <h5 class="initial-38-3"><?php echo htmlspecialchars($Restaurantname); ?></h5>
                    <h5 class="text-break initial-38-4"><?php echo htmlspecialchars($Restaurantaddress); ?></h5>
                    <h5 class="text-muted">${new Date().toLocaleDateString('en-GB')} ${new Date().toLocaleTimeString('en-GB')}</h5>
                    <h5><span>Phone</span> <span>:</span> <span><?php echo htmlspecialchars($Restaurantphone); ?></span></h5>
                </div>

                <h5 class="d-flex">
                    <span>Order Type</span>
                    <span>${servingOption}</span>
                </h5>

                <div class="border border-dashed border-secondary p-3 rounded">
                    <h5 class="d-flex">
                        <span class="text-muted">Order ID</span>
                        <span>${invoiceNumber}</span>
                    </h5>
                </div>

                ${deliveryAddressHtml}
                ${pickupNameHtml}
                <h3>Products:</h3>
                <ul>
                    ${Object.values(productQuantities).map(product => {
                        // Calculate total price for this item
                        const itemTotalPrice = (product.price * product.quantity).toFixed(2);
                        return `
                            <li>${product.quantity} x ${product.name} - £${itemTotalPrice}</li>
                        `;
                    }).join('')}
                </ul>
                
                <div class="border-bottom-dashed mb-3"></div>
                <div>
                    <div class="px-3">
                        <dl class="row text-right">
                            <dt class="col-6 text-left text-muted">Items Price</dt>
                            <dd class="col-6">£${subtotal.toFixed(2)}</dd>
                            <dd class="col-12 border-bottom-dashed mb-2"></dd>
                            <dt class="col-6 text-left text-muted">Discount</dt>
                            <dd class="col-6">- £${discountAmount.toFixed(2)}</dd>
                            <dt class="col-6 text-left text-muted">Delivery charge</dt>
                            <dd class="col-6">£${deliveryChargeAmount.toFixed(2)}</dd>
                            <dd class="col-12 border-bottom-dashed mb-2"></dd>
                            <dt class="col-6 text-left fw-500 fz-20px">Total</dt>
                            <dd class="col-6 fz-20px fw-500">£${(subtotal + deliveryChargeAmount - discountAmount).toFixed(2)}</dd>
                        </dl>
                    </div>
                </div>

                <dd class="col-12 border-bottom-dashed mb-2"></dd>
                <div class="d-flex flex-row justify-content-between">
                    <span class="text-capitalize d-flex"><span>Paid by</span> <span>:</span> <span>${paymentMethod}</span></span>
                </div>
                <dd class="col-12 border-bottom-dashed my-2"></dd>
                <h5 class="text-center pt-1 justify-content-center mb-0">
                    <span class="d-block fw-500">THANK YOU</span>
                </h5>
                <div class="text-center">For ordering food from <?php echo htmlspecialchars($Restaurantname); ?></div>
                <dd class="col-12 border-bottom-dashed my-2"></dd>
                <span class="d-block text-center">© <?php echo date("Y"); ?> <?php echo htmlspecialchars($Restaurantname); ?>. All rights reserved Powered By Foodspot</span>
            </div>
        </body>
        </html>
    `;

    // Create a hidden iframe for printing
    const iframe = document.createElement('iframe');
    iframe.style.position = 'absolute';
    iframe.style.width = '0';
    iframe.style.height = '0';
    iframe.style.border = 'none';
    document.body.appendChild(iframe);

    const iframeDoc = iframe.contentWindow.document;
    iframeDoc.open();
    iframeDoc.write(receiptContent);
    iframeDoc.close();

    iframe.contentWindow.focus();
    iframe.contentWindow.print();

    // Clean up after printing
    iframe.addEventListener('load', () => {
        iframe.contentWindow.onafterprint = () => {
            document.body.removeChild(iframe);
        };
    });
}







// Function to remove product from the cart list
function removeProductFromList(key) {
    if (productQuantities[key].quantity > 1) {
        productQuantities[key].quantity -= 1;
    } else {
        delete productQuantities[key];
    }

    updateProductList();
}
       // Function to add product to the cart list
function addProductToList(name, price, variations = [], id) {
            const selectedProducts = document.getElementById('selected-products');
            const productKey = `${id}|${name}|${price}`;

            if (productQuantities[productKey]) {
                productQuantities[productKey].quantity += 1;
            } else {
                productQuantities[productKey] = { id: id, name: name, price: price, quantity: 1, variations: variations };
            }

            updateProductList();
            updateTotalAndAmountToPay();
            
        }
        
function removeProductFromList(key) {
    if (productQuantities[key].quantity > 1) {
        productQuantities[key].quantity -= 1;
    } else {
        delete productQuantities[key];
    }

    updateProductList();  // Update the product list
    updateTotalAndAmountToPay(); // Update the total and amount to pay
}

// Function to clear the entire cart
function clearCart() {
    productQuantities = {}; // Reset the product quantities to an empty object
    updateProductList(); // Update the displayed product list
    updateTotalAndAmountToPay(); // Update the total amount to pay
}


// Function to remove all quantities of a product from the cart
function removeAllFromList(key) {
    delete productQuantities[key]; // Remove the product entirely
    updateProductList(); // Update the cart list
    updateTotalAndAmountToPay(); // Update the total and amount to pay after removal
}


 // Function to update the cart list
function updateProductList() {
    const selectedProducts = document.getElementById('selected-products');
    const totalPriceElem = document.getElementById('total-price');
    selectedProducts.innerHTML = ''; // Clear the list before re-rendering
    let newTotal = 0;

    // Iterate over productQuantities using the updated key format
    for (const [key, product] of Object.entries(productQuantities)) {
        const listItem = document.createElement('li');
        listItem.classList.add('product-item');

        // Calculate the total price for this product (price * quantity)
        const totalProductPrice = product.price * product.quantity;

        // Product details
        const productDetails = document.createElement('div');
        productDetails.classList.add('product-details');
        productDetails.innerHTML = `
            <div class="product-name">
                <strong>${product.quantity}</strong> x ${product.name}
            </div>
            <div class="price"><strong>£${totalProductPrice.toFixed(2)}</strong></div>
        `;

        // Variations details
        let variationsHtml = '';
        if (product.variations && product.variations.length > 0) {
            product.variations.forEach(variation => {
                variationsHtml += `<div class="variation">${variation.name}: ${variation.selected ? variation.selected.join(', ') : 'None'}</div>`;
            });
        }

        const variationsContainer = document.createElement('div');
        variationsContainer.classList.add('product-variations');
        variationsContainer.innerHTML = variationsHtml;

        // Remove button
const removeButton = document.createElement('button');
removeButton.classList.add('remove-btn');
removeButton.textContent = 'X';
removeButton.setAttribute('data-key', key);

// Handle single and double click
let clickTimer = null;
removeButton.addEventListener('click', (e) => {
    const key = e.target.getAttribute('data-key');
    // Single click action
    clickTimer = setTimeout(() => {
        removeProductFromList(key); // Remove one item
    }, 250); // Delay for single click (adjust as needed)
});

removeButton.addEventListener('dblclick', (e) => {
    clearTimeout(clickTimer); // Prevent single click action
    const key = e.target.getAttribute('data-key');
    removeAllFromList(key); // Remove all quantities of the product
    updateTotalAndAmountToPay(); // Update the total and amount to pay after removal
});



        // Append to list item
        listItem.appendChild(productDetails);
        listItem.appendChild(variationsContainer);
        listItem.appendChild(removeButton);

        selectedProducts.appendChild(listItem);
        newTotal += totalProductPrice;  // Add the total price for this product
    }

    totalPriceElem.textContent = `£${newTotal.toFixed(2)}`;
}

// Function to remove all quantities of a product from the cart
function removeAllFromList(key) {
    delete productQuantities[key]; // Remove the product entirely
    updateProductList(); // Update the cart list
}

const clearCartButton = document.getElementById('clear-cart-button');
if (clearCartButton) {
    clearCartButton.addEventListener('click', () => {
        clearCart(); // Call the function to clear the cart immediately
    });
} else {
    console.error('Clear Cart Button not found! Ensure it exists in your HTML.');
}

// Open discount popup
        document.getElementById('discount-btn').addEventListener('click', () => {
            document.getElementById('discount-popup').style.display = 'block';
        });

        // Close discount popup
        document.getElementById('close-discount-popup').addEventListener('click', () => {
            document.getElementById('discount-popup').style.display = 'none';
        });

        // Save discount amount
        document.getElementById('discount-form').addEventListener('submit', (e) => {
            e.preventDefault();
            discountAmount = parseFloat(document.getElementById('discount-amount-input').value) || 0;
            document.getElementById('discount-container').style.display = 'block';
            updateTotalAndAmountToPay();
            document.getElementById('discount-popup').style.display = 'none';
        });

        // Open delivery charge popup
        document.getElementById('delivery-charge-btn').addEventListener('click', () => {
            document.getElementById('delivery-charge-popup').style.display = 'block';
        });

        // Close delivery charge popup
        document.getElementById('close-delivery-charge-popup').addEventListener('click', () => {
            document.getElementById('delivery-charge-popup').style.display = 'none';
        });

        // Save delivery charge amount
        document.getElementById('delivery-charge-form').addEventListener('submit', (e) => {
            e.preventDefault();
            deliveryChargeAmount = parseFloat(document.getElementById('delivery-charge-input').value) || 0;
            document.getElementById('delivery-charge-container').style.display = 'block';
            updateTotalAndAmountToPay();
            document.getElementById('delivery-charge-popup').style.display = 'none';
        });

        

  // JavaScript to handle the popups

// Function to clear the Pickup Name
function clearPickupName() {
    // Clear the pickup name text
    document.getElementById('pickup-name-text').textContent = '';

    // Hide the pickup name container
    document.getElementById('pickup-name-container').style.display = 'none';

    // Clear the input field in the pickup name popup (optional)
    document.getElementById('customer-name').value = '';
}

// Event listener for Eat-In button
document.getElementById('eat-in-btn').addEventListener('click', function() {
    clearPickupName();
    // You can add more logic for Eat-In option if needed
});

// Event listener for Take-Away button
document.getElementById('take-away-btn').addEventListener('click', function() {
    clearPickupName();
    // You can add more logic for Take-Away option if needed
});

// Event listener for Delivery button
document.getElementById('delivery-btn').addEventListener('click', function() {
    clearPickupName();
    // You can add more logic for Delivery option if needed
});

// Existing Event listener for Pick Up button
document.getElementById('pick-up-btn').addEventListener('click', function() {
    document.getElementById('pick-up-popup').style.display = 'block';
});

// Close the Pick Up name popup
document.getElementById('close-pick-up-popup').addEventListener('click', function() {
    document.getElementById('pick-up-popup').style.display = 'none';
});

// Handle the Pick Up name form submission
var pickupName; // Define this outside the function

document.getElementById('pick-up-form').addEventListener('submit', function(event) {
    event.preventDefault(); // Prevent the form from submitting

    var customerName = document.getElementById('customer-name').value;

    if (customerName.trim() !== "") {
        // Display the Pickup Name in the invoice view
        document.getElementById('pickup-name-text').textContent = customerName;
        document.getElementById('pickup-name-container').style.display = 'block';

        // Save the pickup name for later use in the invoice
        pickupName = customerName; // Store the customer name

        // Close the Pick Up name popup
        document.getElementById('pick-up-popup').style.display = 'none';
    } else {
       // alert("Please enter a name for pickup.");
        showError('Please enter a name for pickup.');
    }
});



// Optional: Handle the edit button for Pickup Name
document.getElementById('edit-pickup-name-btn').addEventListener('click', function() {
    document.getElementById('pick-up-popup').style.display = 'block';
});

function updateDeliveryAddressDisplay() {
    const addressContainer = document.getElementById('delivery-address-container');
    const addressText = document.getElementById('delivery-address-text');
    const editAddressBtn = document.getElementById('edit-address-btn');
    
    if (deliveryAddress) {
        addressContainer.style.display = 'block';
        addressText.innerHTML = `
            ${deliveryAddress.house_number}, ${deliveryAddress.street}, ${deliveryAddress.town}, ${deliveryAddress.postcode}<br>
            Phone: ${deliveryAddress.phone}
        `;
    } else {
        addressContainer.style.display = 'none';
    }
}

// Handle edit address button click
document.getElementById('edit-address-btn').addEventListener('click', () => {
    document.getElementById('delivery-address-popup').style.display = 'flex';
});

// Show variation popup
        function showVariationPopup(name, price, variations, id) {
            const popup = document.getElementById('variation-popup');
            const variationOptions = document.getElementById('variation-options');
            variationOptions.innerHTML = '';

            variations.forEach((variation, index) => {
                const li = document.createElement('li');
                const title = document.createElement('h3');
                title.textContent = variation.name;
                li.appendChild(title);

                variation.values.forEach(value => {
                    const button = document.createElement('div');
                    button.classList.add('option-button');
                    button.textContent = `${value.label} - £${parseFloat(value.optionPrice).toFixed(2)}`;
                    button.dataset.optionPrice = value.optionPrice;
                    button.dataset.groupIndex = index;
                    button.dataset.value = value.label;

                    button.addEventListener('click', () => {
                        const groupButtons = document.querySelectorAll(`[data-group-index="${index}"]`);
                        if (variation.type === 'single') {
                            groupButtons.forEach(btn => btn.classList.remove('selected'));
                        } else if (variation.type === 'multi') {
                            const selectedButtons = document.querySelectorAll(`[data-group-index="${index}"].selected`);
                            const min = parseInt(button.parentNode.dataset.min, 10);
                            const max = parseInt(button.parentNode.dataset.max, 10);

                            if (selectedButtons.length >= max && !button.classList.contains('selected')) {
                              //  alert(`You can only select up to ${max} options for ${variation.name}.`);
                                showError(`You can only select up to ${max} options for ${variation.name}.`);
                                return;
                            }
                        }
                        button.classList.toggle('selected');
                    });

                    li.appendChild(button);
                });

                li.dataset.required = variation.required === 'on' ? 'true' : 'false';
                li.dataset.min = variation.min;
                li.dataset.max = variation.max;
                li.dataset.groupIndex = index;
                li.dataset.type = variation.type;

                variationOptions.appendChild(li);
            });

            document.getElementById('add-variation').onclick = () => {
                const selectedOptions = document.querySelectorAll('.option-button.selected');
                let valid = true;

                document.querySelectorAll('#variation-options > li').forEach(group => {
                    const groupIndex = group.dataset.groupIndex;
                    const min = parseInt(group.dataset.min, 10);
                    const max = parseInt(group.dataset.max, 10);
                    const type = group.dataset.type;
                    const selectedCount = document.querySelectorAll(`[data-group-index="${groupIndex}"].selected`).length;

                    if (group.dataset.required === 'true') {
                        if (type === 'single' && selectedCount !== 1) {
                            valid = false;
                           // alert(`Please select exactly 1 option for ${group.querySelector('h3').textContent}.`);
                            showError(`Please select exactly 1 option for ${group.querySelector('h3').textContent}.`);
                        } else if (type === 'multi' && (selectedCount < min || selectedCount > max)) {
                            valid = false;
                          //  alert(`Please select between ${min} and ${max} options for ${group.querySelector('h3').textContent}.`);
                            showError(`Please select between ${min} and ${max} options for ${group.querySelector('h3').textContent}.`);
                        }
                    }
                });

                if (valid) {
                    const optionPrices = Array.from(selectedOptions).reduce((acc, option) => acc + parseFloat(option.dataset.optionPrice), 0);
                    const variationText = Array.from(selectedOptions).map(btn => btn.textContent).join(', ');
                    const totalPrice = price + optionPrices;

                    addProductToList(name + ' - ' + variationText, totalPrice, [], id);
                    popup.style.display = 'none';
                }
            };

            document.getElementById('close-popup').addEventListener('click', () => {
                popup.style.display = 'none';
            });

            popup.style.display = 'block';
        }


document.addEventListener('DOMContentLoaded', function() {
    // View Buttons
    const invoiceViewBtn = document.getElementById('invoice-view-btn');
    const onlineViewBtn = document.getElementById('online-view-btn');
    const posOrdersViewBtn = document.getElementById('pos-orders-view-btn');
    
    // View Containers
    const invoiceView = document.getElementById('invoice-view');
    const onlineView = document.getElementById('online-view');
    const posOrdersView = document.getElementById('pos-orders-view');
    
    // Popup Containers
    const variationPopup = document.getElementById('variation-popup');
    const discountPopup = document.getElementById('discount-popup');
    const deliveryChargePopup = document.getElementById('delivery-charge-popup');
    const deliveryAddressPopup = document.getElementById('delivery-address-popup');
    const pickUpPopup = document.getElementById('pick-up-popup');

    // Function to show the selected view and hide others
    function showView(viewToShow, btnToActivate) {
        invoiceView.classList.remove('active');
        onlineView.classList.remove('active');
        posOrdersView.classList.remove('active');

        viewToShow.classList.add('active');
        
        // Remove active class from all buttons
    invoiceViewBtn.classList.remove('active-btn');
    onlineViewBtn.classList.remove('active-btn');
    posOrdersViewBtn.classList.remove('active-btn');

    // Add active class to the clicked button
    btnToActivate.classList.add('active-btn');
    }

    // Event listener for Invoice View button
    invoiceViewBtn.addEventListener('click', function() {
        showView(invoiceView, invoiceViewBtn);
    });

    // Event listener for Online View button
    onlineViewBtn.addEventListener('click', function() {
        showView(onlineView, onlineViewBtn);
    });

    // Event listener for POS Orders View button
    posOrdersViewBtn.addEventListener('click', function() {
        showView(posOrdersView, posOrdersViewBtn);
    });

    // Function to show a popup and hide others
    function showPopup(popupToShow) {
        const popups = document.querySelectorAll('.popup, .modal');
        popups.forEach(popup => {
            popup.classList.remove('show');
        });
        popupToShow.classList.add('show');
    }

    // Function to hide a popup
    function hidePopup(popup) {
        popup.classList.remove('show');
    }

    // Event listeners for closing popups
    document.querySelectorAll('.close-btn').forEach(btn => {
        btn.addEventListener('click', function() {
            hidePopup(this.closest('.popup'));
        });
    });

    // Specific close buttons
    document.getElementById('close-popup').addEventListener('click', function() {
        hidePopup(variationPopup);
    });

    // Click event for product list to show variation popup
    document.querySelector('.product-list').addEventListener('click', function(event) {
        if (event.target.closest('.product')) {
            const product = event.target.closest('.product');
            const variations = product.getAttribute('data-variations');
            if (variations && variations !== '[]') {
                showPopup(variationPopup);
            }
        }
    });

    // Example usage of additional popups
    document.getElementById('discount-btn').addEventListener('click', function() {
        showPopup(discountPopup);
    });

    document.getElementById('delivery-charge-btn').addEventListener('click', function() {
        showPopup(deliveryChargePopup);
    });

    document.getElementById('delivery-address-btn').addEventListener('click', function() {
        showPopup(deliveryAddressPopup);
    });

    document.getElementById('pick-up-btn').addEventListener('click', function() {
        showPopup(pickUpPopup);
    });

    // Optional: Hide popups when clicking outside of them
    window.addEventListener('click', function(event) {
        if (event.target.classList.contains('popup') || event.target.classList.contains('modal')) {
            hidePopup(event.target);
        }
    });

    // Payment method selection
    function selectPaymentMethod(selectedButtonId) {
        const paymentButtons = document.querySelectorAll('.payment-btn');
        paymentButtons.forEach(function(button) {
            if (button.id === selectedButtonId) {
                button.classList.add('active');
            } else {
                button.classList.remove('active');
            }
        });
    }

    // Default selection
    selectPaymentMethod('card-btn');

    // Event listeners for payment buttons
    document.getElementById('cash-btn').addEventListener('click', function() {
        selectPaymentMethod('cash-btn');
    });

    document.getElementById('card-btn').addEventListener('click', function() {
        selectPaymentMethod('card-btn');
    });
});


//pick up 
function openPopup(popupId) {
    var popup = document.getElementById(popupId);
    popup.style.display = 'block';
}

// Function to close a popup by its ID
function closePopup(popupId) {
    var popup = document.getElementById(popupId);
    popup.style.display = 'none';
}

// Event listener for the Pick-Up button to open the Pick-Up popup
document.getElementById('pick-up-btn').addEventListener('click', function() {
    openPopup('pick-up-popup');
});

// Event listener for the close button inside the Pick-Up popup
document.getElementById('close-pick-up-popup').addEventListener('click', function() {
    closePopup('pick-up-popup');
});


// food item status on foodspot check 

window.onload = function() {
    // Set a delay of 10 seconds before executing the function
    setTimeout(function() {
        // Select all product elements with a data-id attribute
        const products = document.querySelectorAll('.product-status[data-id]');
        
        products.forEach(product => {
            const productId = product.getAttribute('data-id'); // Get product id from the attribute
            const statusCircle = product.querySelector('.status-circle'); // Select the status circle

            // Make an API request to fetch the status of the product
            fetch(`<?php echo $api; ?>get_food_status.php?id=${productId}`)
                .then(response => response.json())
                .then(data => {
                    if (data.food && data.food.status == 1) {
                        statusCircle.classList.add('green'); // Add green class if status is 1
                    } else {
                        statusCircle.classList.add('red'); // Add red class if status is not 1
                    }
                })
                .catch(error => {
                    console.error('Error fetching food status:', error);
                    statusCircle.classList.add('red'); // Default to red if there's an error
                });
        });
    }, 3000); // 10000 milliseconds = 10 seconds
};



    </script>
</body>
</html>