<?php
require __DIR__ . '/vendor/autoload.php';  // Ensure this path is correct

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

try {
    // Database connection for POS
    $pdo = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Fetch invoices based on serving option and date range
    $servingOption = isset($_GET['serving_option']) ? $_GET['serving_option'] : 'all';
    $startDate = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d');
    $endDate = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d', strtotime('tomorrow'));

    $query = "SELECT sales.id, sales.created_at, sales.payment_method, sales.transaction_reference, 
              COALESCE(SUM(sales.order_amount), 0) AS total_amount
              FROM sales
              LEFT JOIN sales_details ON sales.id = sales_details.order_id
              WHERE sales.created_at BETWEEN :start_date AND :end_date";

    if ($servingOption !== 'all') {
        $query .= " AND sales.transaction_reference = :serving_option";
    }

    $query .= " GROUP BY sales.id
                ORDER BY sales.id DESC";

    $stmt = $pdo->prepare($query);
    $params = [
        'start_date' => $startDate,
        'end_date' => $endDate
    ];

    if ($servingOption !== 'all') {
        $params['serving_option'] = $servingOption;
    }

    $stmt->execute($params);
    $invoices = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "Connection failed: " . $e->getMessage();
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Invoices</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
        }
        .header {
            background-color: #333;
            color: #fff;
            padding: 10px;
            text-align: center;
        }
        .top-bar {
            display: flex;
            justify-content: center;
            background-color: #f4f4f4;
            padding: 10px;
        }
        .top-bar button {
            padding: 10px;
            border: 1px solid #ddd;
            cursor: pointer;
            margin: 0 5px;
        }
        .top-bar button.active {
            background-color: #333;
            color: #fff;
        }
        .date-filter {
            display: flex;
            justify-content: center;
            padding: 10px;
            background-color: #f4f4f4;
            margin-bottom: 10px;
        }
        .date-filter button, .date-filter input {
            margin: 0 5px;
            padding: 5px 10px;
        }
        .container {
            padding: 20px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }
        table, th, td {
            border: 1px solid #ddd;
        }
        th, td {
            padding: 10px;
            text-align: center;
        }
        th {
            background-color: #f4f4f4;
        }
        .actions button {
            padding: 5px 10px;
            margin: 2px;
            cursor: pointer;
        }
    </style>
</head>
<body>
    <div class="header">
        <h1>Invoices</h1>
    </div>
    <div class="date-filter">
        <button onclick="filterToday()">Today</button>
        <input type="date" id="start-date" value="<?php echo date('Y-m-d'); ?>">
        <input type="date" id="end-date" value="<?php echo date('Y-m-d', strtotime('tomorrow')); ?>">
        <button onclick="filterByDate()">Search</button>
    </div>
    <div class="top-bar">
        <button class="filter-btn" data-option="all" <?php echo $servingOption === 'all' ? 'class="active"' : ''; ?>>All</button>
        <button class="filter-btn" data-option="Eat-In" <?php echo $servingOption === 'Eat-In' ? 'class="active"' : ''; ?>>Eat-In</button>
        <button class="filter-btn" data-option="Take-Away" <?php echo $servingOption === 'Take-Away' ? 'class="active"' : ''; ?>>Take-Away</button>
        <button class="filter-btn" data-option="Delivery" <?php echo $servingOption === 'Delivery' ? 'class="active"' : ''; ?>>Delivery</button>
    </div>
    <div class="container">
        <table>
            <thead>
                <tr>
                    <th>Invoice Number</th>
                    <th>Date</th>
                    <th>Payment Method</th>
                    <th>Serving Option</th>
                    <th>Amount</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($invoices)): ?>
                    <tr>
                        <td colspan="6">No invoices found</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($invoices as $invoice): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($invoice['id']); ?></td>
                            <td><?php echo htmlspecialchars($invoice['created_at']); ?></td>
                            <td><?php echo htmlspecialchars($invoice['payment_method']); ?></td>
                            <td><?php echo htmlspecialchars($invoice['transaction_reference']); ?></td>
                            <td><?php echo htmlspecialchars(number_format($invoice['total_amount'], 2)); ?></td>
                            <td class="actions">
                                <button onclick="viewInvoice('<?php echo htmlspecialchars($invoice['id']); ?>')">View</button>
                                <button onclick="reprintInvoice('<?php echo htmlspecialchars($invoice['id']); ?>')">Reprint</button>
                                <button onclick="editInvoice('<?php echo htmlspecialchars($invoice['id']); ?>')">Edit</button>
                                <button onclick="deleteInvoice('<?php echo htmlspecialchars($invoice['id']); ?>')">Delete</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
    <script>
        // Function to filter invoices by date range
        function filterByDate() {
            const startDate = document.getElementById('start-date').value;
            const endDate = document.getElementById('end-date').value;
            window.location.href = `invoices.php?start_date=${startDate}&end_date=${endDate}`;
        }

        // Function to filter invoices to today's date
        function filterToday() {
            const today = new Date();
            const startDate = today.toISOString().split('T')[0];
            const endDate = new Date(today.getTime() + 24*60*60*1000).toISOString().split('T')[0]; // Next day
            document.getElementById('start-date').value = startDate;
            document.getElementById('end-date').value = endDate;
            filterByDate();
        }

        // Attach event listeners to filter buttons
        document.querySelectorAll('.filter-btn').forEach(button => {
            button.addEventListener('click', () => {
                const option = button.getAttribute('data-option');
                const startDate = document.getElementById('start-date').value;
                const endDate = document.getElementById('end-date').value;
                window.location.href = `invoices.php?serving_option=${option}&start_date=${startDate}&end_date=${endDate}`;
            });
        });

        function viewInvoice(id) {
            window.location.href = `view_invoice.html?id=${id}`;
        }

        function reprintInvoice(id) {
            window.open(`print_invoice.php?id=${id}`, '_blank');
        }

        function editInvoice(id) {
            window.location.href = `edit_invoice.php?id=${id}`;
        }

        function deleteInvoice(id) {
            if (confirm('Are you sure you want to delete this invoice?')) {
                fetch(`delete_invoice.php?id=${id}`, {
                    method: 'DELETE'
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        window.location.reload();
                    } else {
                        alert('Failed to delete invoice.');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('An error occurred while deleting the invoice.');
                });
            }
        }
    </script>
</body>
</html>
