<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require __DIR__ . '/vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

header('Content-Type: application/json');

try {
    // Database connection
    $pdo = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Read input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Debugging: Log received data
    error_log('Received data: ' . print_r($data, true));

    if (!isset($data['paymentMethod'], $data['servingOption'], $data['products'])) {
        echo json_encode(['success' => false, 'error' => 'Missing required data']);
        exit();
    }
    $orderNote = isset($data['orderNote']) ? $data['orderNote'] : null;
    $paymentMethod = htmlspecialchars(trim($data['paymentMethod']));
    $servingOption = htmlspecialchars(trim($data['servingOption']));
    $products = $data['products'];
    $deliveryAddress = isset($data['deliveryAddress']) ? json_encode($data['deliveryAddress']) : null;
    $discountAmount = isset($data['coupon_discount_amount']) ? (float)$data['coupon_discount_amount'] : 0;
    $deliveryCharge = isset($data['delivery_charge']) ? (float)$data['delivery_charge'] : 0;
    $pickupName = isset($data['pickupName']) ?htmlspecialchars(trim($data['pickupName'])) : null;
    $orderType = $servingOption; // Assuming orderType is same as servingOption

    // Validate products
    if (!is_array($products) || empty($products)) {
        echo json_encode(['success' => false, 'error' => 'Invalid products data']);
        exit();
    }

    // Calculate order amount
    $orderAmount = array_reduce($products, function($sum, $product) {
        return $sum + (float)$product['price'] * (int)$product['quantity'];
    }, 0);

    // Calculate final amount to pay
    $totalAmount = $orderAmount + $deliveryCharge - $discountAmount;

    // Determine payment status
   $paymentStatus = ($servingOption === 'Delivery' || $servingOption === 'Pick-Up') ? 'unpaid' : 'paid';
    $transactionReference = ($servingOption === 'Delivery' || $servingOption === 'Pick-Up') ? 'NILL' : $paymentMethod;

    // Get current timestamp
    $createdAt = date('Y-m-d H:i:s');

    // Begin transaction
    $pdo->beginTransaction();

    // Get the last value of the id column from the sales table
    $lastIdQuery = $pdo->query("SELECT id FROM sales ORDER BY id DESC LIMIT 1");
    $lastIdResult = $lastIdQuery->fetch(PDO::FETCH_ASSOC);
    $invoiceNumber = $lastIdResult ? $lastIdResult['id'] + 1 : 1;

    // Debugging: Log orderType and invoiceNumber
    error_log("Order Type: " . $orderType);
    error_log("Invoice Number: " . $invoiceNumber);

    // Insert into sales table
    $insertSalesStmt = $pdo->prepare("
        INSERT INTO sales (id, order_amount, payment_method, payment_status, transaction_reference, created_at, delivery_address, coupon_discount_amount, delivery_charge, total_amount, pickup_user, order_status, order_type, order_note)
        VALUES (:id, :order_amount, :payment_method, :payment_status, :transaction_reference, :created_at, :delivery_address, :coupon_discount_amount, :delivery_charge, :total_amount, :pickup_user, :order_status, :order_type, :order_note)
    ");
    $insertSalesStmt->execute([
        'id' => $invoiceNumber,
        'order_amount' => $orderAmount,
        'payment_method' => $transactionReference,
        'payment_status' => $paymentStatus,
        'transaction_reference' => $transactionReference,
        'created_at' => $createdAt,
        'delivery_address' => $deliveryAddress,
        'coupon_discount_amount' => $discountAmount,
        'delivery_charge' => $deliveryCharge,
        'total_amount' => $totalAmount,
        'pickup_user' => $pickupName, // Store pickupName in user_id column
        'order_type' => $orderType,
        'order_status' => 'confirmed',
        'order_note' => $orderNote
    ]);

    // Insert into sales_details table
    $insertSalesDetailsStmt = $pdo->prepare("
        INSERT INTO sales_details (order_id, food_id, food_details, quantity, price, variation)
        VALUES (:order_id, :food_id, :food_details, :quantity, :price, :variation)
    ");

    foreach ($products as $product) {
        $insertSalesDetailsStmt->execute([
            'order_id' => $invoiceNumber,
            'food_id' => isset($product['id']) ? (int)$product['id'] : null,
            'food_details' => htmlspecialchars(trim($product['name'])),
            'quantity' => (int)$product['quantity'],
            'price' => (float)$product['price'],
            'variation' => isset($product['variation']) ? htmlspecialchars(trim($product['variation'])) : ''
        ]);
    }

    // Commit transaction
    $pdo->commit();

    // Return success response with invoice number and total price
    echo json_encode(['success' => true, 'invoiceNumber' => $invoiceNumber, 'totalPrice' => $totalAmount]);

} catch (PDOException $e) {
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    error_log('PDOException: ' . $e->getMessage());
    echo json_encode(['success' => false, 'error' => 'Database error occurred']);
} catch (Exception $e) {
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    error_log('Exception: ' . $e->getMessage());
    echo json_encode(['success' => false, 'error' => 'An error occurred']);
}
?>
