<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require __DIR__ . '/vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

header('Content-Type: application/json');

try {
    // Database connection
    $pdo = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Read input data
    $orders = json_decode(file_get_contents('php://input'), true);

    if (!is_array($orders) || empty($orders)) {
        echo json_encode(['success' => false, 'error' => 'Invalid orders data']);
        exit();
    }

    // Begin transaction
    $pdo->beginTransaction();

    foreach ($orders as $data) {
        if (!isset($data['paymentMethod'], $data['servingOption'], $data['products'])) {
            throw new Exception('Missing required data');
        }

        $paymentMethod = htmlspecialchars(trim($data['paymentMethod']));
        $servingOption = htmlspecialchars(trim($data['servingOption']));
        $products = $data['products'];
        $deliveryAddress = isset($data['deliveryAddress']) ? json_encode($data['deliveryAddress']) : null;
        $discountAmount = isset($data['coupon_discount_amount']) ? (float)$data['coupon_discount_amount'] : 0;
        $deliveryCharge = isset($data['delivery_charge']) ? (float)$data['delivery_charge'] : 0;

        // Validate products
        if (!is_array($products) || empty($products)) {
            throw new Exception('Invalid products data');
        }

        // Calculate order amount
        $orderAmount = array_reduce($products, function($sum, $product) {
            return $sum + (float)$product['price'] * (int)$product['quantity'];
        }, 0);

        // Calculate final amount to pay
        $totalTaxAmount = $orderAmount + $deliveryCharge - $discountAmount;

        // Determine payment status
        $paymentStatus = ($servingOption === 'Delivery') ? 'unpaid' : 'paid';
        $transactionReference = ($servingOption === 'Delivery') ? 'N/A' : $paymentMethod;

        // Get current timestamp
        $createdAt = date('Y-m-d H:i:s');

        // Get the last value of the id column from the sales table
        $lastIdQuery = $pdo->query("SELECT id FROM sales ORDER BY id DESC LIMIT 1");
        $lastIdResult = $lastIdQuery->fetch(PDO::FETCH_ASSOC);
        $invoiceNumber = $lastIdResult ? $lastIdResult['id'] + 1 : 1;

        // Insert into sales table
        $insertSalesStmt = $pdo->prepare("
            INSERT INTO sales (id, order_amount, payment_method, payment_status, transaction_reference, created_at, delivery_address, coupon_discount_amount, delivery_charge, total_tax_amount)
            VALUES (:id, :order_amount, :payment_method, :payment_status, :transaction_reference, :created_at, :delivery_address, :coupon_discount_amount, :delivery_charge, :total_tax_amount)
        ");
        $insertSalesStmt->execute([
            'id' => $invoiceNumber,
            'order_amount' => $orderAmount,
            'payment_method' => $paymentMethod,
            'payment_status' => $paymentStatus,
            'transaction_reference' => $transactionReference,
            'created_at' => $createdAt,
            'delivery_address' => $deliveryAddress,
            'coupon_discount_amount' => $discountAmount,
            'delivery_charge' => $deliveryCharge,
            'total_tax_amount' => $totalTaxAmount
        ]);

        // Insert into sales_details table
        $insertSalesDetailsStmt = $pdo->prepare("
            INSERT INTO sales_details (order_id, food_id, food_details, quantity, price, variation)
            VALUES (:order_id, :food_id, :food_details, :quantity, :price, :variation)
        ");

        foreach ($products as $product) {
            $insertSalesDetailsStmt->execute([
                'order_id' => $invoiceNumber,
                'food_id' => isset($product['id']) ? (int)$product['id'] : null,
                'food_details' => htmlspecialchars(trim($product['name'])),
                'quantity' => (int)$product['quantity'],
                'price' => (float)$product['price'],
                'variation' => isset($product['variation']) ? htmlspecialchars(trim($product['variation'])) : ''
            ]);
        }
    }

    // Commit transaction
    $pdo->commit();

    // Return success response
    echo json_encode(['success' => true]);

} catch (PDOException $e) {
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    error_log('PDOException: ' . $e->getMessage());
    echo json_encode(['success' => false, 'error' => 'Database error occurred']);
} catch (Exception $e) {
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    error_log('Exception: ' . $e->getMessage());
    echo json_encode(['success' => false, 'error' => 'An error occurred']);
}
?>
