<?php
// Load environment variables from .env file
require 'vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Set headers to allow cross-origin requests and JSON response
header('Access-Control-Allow-Origin: *');
header('Content-Type: application/json');

try {
    // Database connection for fetching data from the login_key
    $pdo2 = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo2->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Fetch data from login_key table where id = 1
    $loginKeyStmt = $pdo2->prepare("
        SELECT 
            api, 
            rest_id,
            rest_link
        FROM login_key 
    ");
    $loginKeyStmt->execute();
    $loginKeyResult = $loginKeyStmt->fetch(PDO::FETCH_ASSOC);

    if ($loginKeyResult) {
        $api = $loginKeyResult['api'];
        $restaurantId = $loginKeyResult['rest_id'];
        $restlinkapi = $loginKeyResult['rest_link'];

        // Construct the API URL using the fetched API domain and restaurantId
        $apiUrl = "{$api}online_food_sync.php?id={$restaurantId}";

        // Fetch data from the primary API
        $apiResponse = file_get_contents($apiUrl);
        $data = json_decode($apiResponse, true);

        if (isset($data['error'])) {
            echo json_encode(['error' => 'Failed to fetch data from the API: ' . $data['error']]);
            exit();
        }

        if (!isset($data['foods']) || !isset($data['categories'])) {
            echo json_encode(['error' => 'Invalid data structure from the API.']);
            exit();
        }

        // Format data for the secondary API
        $formattedData = [
            'foods' => array_map(function($food) use ($restaurantId) {
                return [
                    'id' => $food['id'],
                    'name' => $food['name'],
                    'image' => $food['image'],
                    'category_id' => $food['category_id'],
                    'variations' => $food['variations'],
                    'price' => $food['price'],
                    'discount_type' => $food['discount_type'],
                    'pos_price' => $food['pos_price'] ?? null,  // Ensure 'pos_price' is set or defaults to null
                    'restaurant_id' => $restaurantId  // Use the provided 'restaurant_id' or default to fetched 'restaurantId'
                ];
            }, $data['foods']),
            'categories' => array_map(function($category) {
                return [
                    'id' => $category['id'],
                    'name' => $category['name']
                ];
            }, $data['categories'])
        ];

        // Log data being sent to the secondary API
        error_log("Formatted data to push: " . print_r($formattedData, true));

        // Secondary database API URL
        $secondaryApiUrl = "{$restlinkapi}sync_food.php";

        // Use cURL to send formatted data to the secondary API
        $ch = curl_init($secondaryApiUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($formattedData));
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Accept: application/json'
        ]);
        $apiResult = curl_exec($ch);
        $apiResultJson = json_decode($apiResult, true);
        curl_close($ch);

        // Log API result
        error_log("Secondary API result: " . print_r($apiResultJson, true));

        // Check if the data was successfully sent to the secondary database
        if (isset($apiResultJson['error'])) {
            echo json_encode(['error' => 'Failed to push data to the secondary database: ' . $apiResultJson['error']]);
            exit();
        }

        // Database connection to the Invoice database
        $pdoInvoice = new PDO(
            "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
            $_ENV['INVOICE_DB_USER'],
            $_ENV['INVOICE_DB_PASSWORD']
        );
        $pdoInvoice->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Insert or update food data in the local Invoice database
        $insertFoodStmt = $pdoInvoice->prepare("
            INSERT INTO food (id, name, image, category_id, variations, price, discount_type, pos_price, restaurant_id)
            VALUES (:id, :name, :image, :category_id, :variations, :price, :discount_type, :pos_price, :restaurant_id)
            ON DUPLICATE KEY UPDATE 
                name = VALUES(name),
                image = VALUES(image),
                category_id = VALUES(category_id),
                variations = VALUES(variations),
                price = VALUES(price),
                discount_type = VALUES(discount_type),
                pos_price = VALUES(pos_price),
                restaurant_id = VALUES(restaurant_id)
        ");

        foreach ($data['foods'] as $food) {
            $insertFoodStmt->execute([
                'id' => $food['id'],
                'name' => $food['name'],
                'image' => $food['image'],
                'category_id' => $food['category_id'],
                'variations' => $food['variations'],
                'price' => $food['price'],
                'discount_type' => $food['discount_type'],
                'pos_price' => $food['pos_price'] ?? null,  // Ensure 'pos_price' is handled properly
                'restaurant_id' => $restaurantId
            ]);
        }

        // Insert or update category data in the local Invoice database
        $insertCatStmt = $pdoInvoice->prepare("
            INSERT INTO categories (id, name)
            VALUES (:id, :name)
            ON DUPLICATE KEY UPDATE 
                name = VALUES(name)
        ");

        foreach ($data['categories'] as $category) {
            $insertCatStmt->execute([
                'id' => $category['id'],
                'name' => $category['name']
            ]);
        }

        echo json_encode(['success' => 'Data successfully updated in both databases.', 'redirect' => '/index.php']);
        

    } else {
        echo json_encode(['error' => 'No associated restaurant ID found.']);
        exit();
    }

} catch (PDOException $e) {
    // Log the error and provide a user-friendly message
    error_log("Database connection failed: " . $e->getMessage());
    echo json_encode(['error' => 'An error occurred while fetching or processing the data.']);
    exit();
} catch (Exception $e) {
    // Handle other exceptions
    error_log($e->getMessage());
    echo json_encode(['error' => 'An unexpected error occurred.']);
    exit();
}
?>
